package com.muyu.domain.model;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.domain.ActivityTeamInfo;
import com.muyu.domain.req.ActivityInfoAddReq;
import lombok.*;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.validation.annotation.Validated;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Null;
import java.util.Date;
import java.util.List;

/**
 * 团购活动添加模型
 *
 * @author: CuiFu Bo
 * @create: 2024-11-22 16:48
 **/

@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class ActivityTeamInfoAddModel {
    /**
     *商品图片
     */
    private String productImage;
    /**
     *活动名称
     */
    private String name;
    /**
     *活动简介
     */
    private String introduction;
    /**
     *商品单位
     */
    private String unit;
    /**
     *商品的轮番图
     */
    private String imagesList;
    /**
     *活动时间
     */
    private Date endTime;
    /**
     *策略类型
     */
    private String strategyType;
    /**
     *策略ID
     */
    private Long strategyId;
    /**
     *排序
     */
    private long sort;
    /**
     *详情
     */
    private String content;

    public static ActivityTeamInfoAddModel activityTeamInfoAddModel (ActivityInfoAddReq req){
        return ActivityTeamInfoAddModel.builder()
                .productImage(req.getProductImage())
                .name(req.getName())
                .introduction(req.getIntroduction())
                .unit(req.getUnit())
                .imagesList(req.getImagesList())
                .endTime(req.getEndTime())
                .strategyType(req.getStrategyType())
                .strategyId(req.getStrategyId())
                .sort(req.getSort())
                .content(req.getContent())
                .build();
    }

    public ActivityTeamInfo activityTeamInfoAdd(){
        return ActivityTeamInfo.builder()
                .productImage(this.getProductImage())
                .name(this.getName())
                .introduction(this.getIntroduction())
                .unit(this.getUnit())
                .imageList(this.getImagesList())
                .endTime(this.getEndTime())
                .strategyType(this.getStrategyType())
                .strategyId(this.getStrategyId())
                .sort(this.getSort())
                .content(this.getContent())
                .build();
    }
}
