package com.muyu.system.team.controller;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.dtflys.forest.annotation.Post;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.domain.ActivityTeamInfo;
import com.muyu.domain.model.ActivitySkuModel;
import com.muyu.domain.model.ActivityTeamInfoAddModel;
import com.muyu.domain.model.ActivityTeamInfoListModel;
import com.muyu.domain.req.ActivityInfoAddReq;
import com.muyu.domain.req.TeamInfoListReq;
import com.muyu.domain.resp.TeamInfoListResp;
import com.muyu.system.team.service.ActivityTeamInfoService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * 商品拼团信息
 * @program: cloud-server
 * @description: 商品拼团信息
 * @author: CuiFu Bo
 * @create: 2024-11-20 21:49
 **/

@RestController
@RequestMapping("/team")
public class ActivityTeamInfoController {

    @Resource
    private ActivityTeamInfoService activityTeamInfoService;

    /**
     * 团购活动列表查询
     * @param teamInfoListReq 分页
     * @return 列表数据
     */
    @PostMapping("/list")
    public Result<TableDataInfo<TeamInfoListResp>> list(@RequestBody TeamInfoListReq teamInfoListReq){
        TableDataInfo<ActivityTeamInfoListModel> tableDataInfo = activityTeamInfoService.query(teamInfoListReq.buildQueryModel());
        List<TeamInfoListResp> listResp = tableDataInfo.getRows().stream().map(TeamInfoListResp::listModerBuild).toList();
        return Result.success(
                new TableDataInfo<>(){{
                    setRows(listResp);
                    setTotal(tableDataInfo.getTotal());
                }}
        );
    }

    /**
     * 拼团活动添加
     * @param activityInfoAddReq  拼团活动
     * @return  拼团活动
     */
    @RequiresPermissions("marketing:marketing:save")
    @PostMapping("/activityInfoAdd")
    public Result<ActivityTeamInfoAddModel> activityInfoAdd(@RequestBody ActivityInfoAddReq activityInfoAddReq){
        activityTeamInfoService.activityAndProductList(ActivityTeamInfoAddModel.activityTeamInfoAddModel(activityInfoAddReq)
                , ActivitySkuModel.activitySkuModel(activityInfoAddReq));
        return Result.success();
    }

}
