package com.muyu.system.team.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.domain.ActivityTeamInfo;
import com.muyu.domain.ActivityTeamProductSkuInfo;
import com.muyu.domain.model.*;
import com.muyu.domain.req.ActivitInfoSkuAddReq;
import com.muyu.system.team.mapper.ActivityTeamInfoMapper;
import com.muyu.system.team.service.ActivityTeamInfoService;
import com.muyu.system.team.service.ActivityTeamOpenInfoService;
import com.muyu.system.team.service.ActivityTeamProductSkuInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 商品拼团信息
 * @author: CuiFu Bo
 * @create: 2024-11-20 21:39
 **/

@Service
public class ActivityTeamInfoServiceImpl extends ServiceImpl<ActivityTeamInfoMapper, ActivityTeamInfo> implements ActivityTeamInfoService {
    @Resource
    private ActivityTeamOpenInfoService activityTeamOpenInfoService;
    @Resource
    private ActivityTeamProductSkuInfoService activityTeamProductSkuInfoService;
    @Override
    public TableDataInfo<ActivityTeamInfoListModel> query(ActivityTeamInfoListQueryModel activityTeamInfoListQueryModel) {
        Page<ActivityTeamInfo> page = new Page<>();

        LambdaQueryWrapper<ActivityTeamInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(StringUtils.isNotEmpty(activityTeamInfoListQueryModel.getKeyWord()),ActivityTeamInfo::getName,activityTeamInfoListQueryModel.getKeyWord());
        queryWrapper.like(StringUtils.isNotEmpty(activityTeamInfoListQueryModel.getStatus()),ActivityTeamInfo::getStatus,activityTeamInfoListQueryModel.getStatus());


        Page<ActivityTeamInfo> activityTeamInfoPage = this.page(activityTeamInfoListQueryModel.bulidPage(), queryWrapper);
        List<ActivityTeamInfo> activityTeamInfoList = activityTeamInfoPage.getRecords();
        List<ActivityTeamInfoListModel> infoListModels = activityTeamInfoList.stream().map(
                activityTeamInfo -> ActivityTeamInfoListModel.infoBuild(activityTeamInfo,
                        (activityTeamInfoListModelBuilder) -> {
                            TeamDiscountPriceModel discountPrice = activityTeamProductSkuInfoService.getDiscountPrice(activityTeamInfo.getId());
                            TeamProductStockModel productStockModer = activityTeamProductSkuInfoService.getProductStockModer(activityTeamInfo.getId());
                            Long teamOpenTypeByOpenTeam = activityTeamOpenInfoService.getTeamOpenTypeByOpenAndTypeTeam(activityTeamInfo.getId());
                            Long teamOpenTypeByInTeam = activityTeamOpenInfoService.getTeamOpenTypeByInAndTypeTeam(activityTeamInfo.getId());
                            return activityTeamInfoListModelBuilder
                                    .addTeamNumber(teamOpenTypeByInTeam)
                                    .openTeamNumber(teamOpenTypeByOpenTeam)
                                    .attendNumber(teamOpenTypeByInTeam + teamOpenTypeByOpenTeam)
                                    .teamPrice(discountPrice.getTeamPrice())
                                    .teamStock(productStockModer.getTeamStock())
                                    .remainStock(productStockModer.getRemainStock())
                                    .build();
                        })).toList();
                        TableDataInfo<ActivityTeamInfoListModel> tableDataInfo = new TableDataInfo<>();
                        tableDataInfo.setTotal(activityTeamInfoPage.getTotal());
                        tableDataInfo.setRows(infoListModels);
                        return tableDataInfo;

    }

    /**
     * 添加拼团活动
     * @param activityTeamInfoAddModel  拼团活动列表
     * @param activitySkuModel 商品规格
     */
    @Override
    public void activityAndProductList(ActivityTeamInfoAddModel activityTeamInfoAddModel, ActivitySkuModel activitySkuModel) {
        //添加品谈活动列表、
        ActivityTeamInfo activityTeamInfo = activityTeamInfoAddModel.activityTeamInfoAdd();
        this.save(activityTeamInfo);

        //添加商品规格表
        List<ActivitInfoSkuAddReq> activitInfoSkuAdd = activitySkuModel.getActivityInfoAdd();
        ArrayList<ActivityTeamProductSkuInfo> skuModelsList = new ArrayList<>();


        ActivityTeamProductSkuInfo activityTeamProductSkuInfo = new ActivityTeamProductSkuInfo();
        activitInfoSkuAdd.stream().forEach(activityAndProductId ->{
            activityTeamProductSkuInfo.setTeamId(activityTeamInfo.getId());
            activityTeamProductSkuInfo.setProductSku(activityAndProductId.getProductSku());
            activityTeamProductSkuInfo.setTeamPrice(activityAndProductId.getTeamPrice());
            activityTeamProductSkuInfo.setTeamStock(activityAndProductId.getTeamStock());
            skuModelsList.add(activityTeamProductSkuInfo);
        });
        activityTeamProductSkuInfoService.saveBatch(skuModelsList);
    }


}

