package com.muyu.system.team.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.domain.ActivityTeamProductSkuInfo;
import com.muyu.domain.model.TeamDiscountPriceModel;
import com.muyu.domain.model.TeamProductStockModel;
import com.muyu.product.cache.ProjectSkuCache;
import com.muyu.product.domain.ProjectSkuInfo;
import com.muyu.system.team.mapper.ActivityTeamProductSkuInfoMapper;
import com.muyu.system.team.service.ActivityTeamProductSkuInfoService;
import lombok.SneakyThrows;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.rmi.server.ServerCloneException;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

/**
商品拼团规格信息表
 * @author: CuiFu Bo
 * @create: 2024-11-20 21:41
 **/


@Service
public class ActivityTeamProductSkuInfoServiceImpl extends ServiceImpl<ActivityTeamProductSkuInfoMapper, ActivityTeamProductSkuInfo> implements ActivityTeamProductSkuInfoService {

    @Resource
    private ProjectSkuCache projectSkuCache;

    @SneakyThrows
    @Override
    public TeamDiscountPriceModel getDiscountPrice(Long teamId) {
        List<ActivityTeamProductSkuInfo> productSkuInfoList = this.getActivityTeamProductSkuInfoByActivity(teamId);
        if(productSkuInfoList.size()>0){


            Optional<TeamDiscountPriceModel> discountPrice = productSkuInfoList.stream()
                .map(activityTeamProductSkuInfo -> {
                    ProjectSkuInfo productPriceList = projectSkuCache.get(activityTeamProductSkuInfo.getProductId(), activityTeamProductSkuInfo.getProductSku());
                    return TeamDiscountPriceModel.of(productPriceList.getPrice(), activityTeamProductSkuInfo.getTeamPrice());
                }).min((o1, o2) -> Double.valueOf(o1.getDiscount() * 100 - o2.getDiscount() * 100).intValue());
        if (discountPrice.isEmpty()) {
            throw new ServerCloneException("团购活动下没有商品绑定");
        }
            return discountPrice.get();
        }
       return TeamDiscountPriceModel.builder()
               .productPrice(BigDecimal.valueOf(0))
               .teamPrice(BigDecimal.valueOf(0))
               .discount(0.00)
               .build();
    }

    @Override
    public TeamProductStockModel getProductStockModer(Long teamId) {
        List<ActivityTeamProductSkuInfo> productSkuInfoList = this.getActivityTeamProductSkuInfoByActivity(teamId);
        return TeamProductStockModel.builder()
                .teamStock(productSkuInfoList.stream().map(ActivityTeamProductSkuInfo::getTeamStock).reduce(0L,Long::sum))
                .remainStock(productSkuInfoList.stream().map(ActivityTeamProductSkuInfo::getProductStock).reduce(0L,Long::sum))
                .build();

    }
}
